@@ -305,7 +305,7 @@ sub new {
    my XML::VWElement $self ;
    {
       no strict 'refs' ;
-      $self = bless [ \%{"$class\::FIELDS"} ], $class ;
+      $self = bless {}, $class ;
    }
 
    my ( $elt_decl ) = @_ ;
@@ -1627,10 +1627,10 @@ Barrie Slaymaker <barries@slaysys.com>
 
 =head1 COPYRIGHT
 
-This module is Copyright 2000, Barrie Slaymaker.  All rights reserved.
+This module is Copyright 2000, 2005 Barrie Slaymaker.  All rights reserved.
 
-This module is licensed under the GPL, version 2.  Please contact me if this
-does not suit your needs.
+This module is licensed under your choice of the Artistic, BSD or
+General Public License.
 
 =cut
 
